==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/gl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está dispoñíbel. Obteña máis información sobre como actualizar.",
    "Channel updated" : "Canle actualizada",
    "Update notifications" : "Actualizar as notificacións",
    "The update server could not be reached since %d days to check for new updates." : "Non foi posíbel acadar o servidor de actualizacións dende hai %d días para comprobar se hai novas actualizacións.",
    "Please check the Nextcloud and server log files for errors." : "Revise os ficheiros de rexistro de Nextcloud e do servidor na busca de erros.",
    "Update to %1$s is available." : "Está dispoñíbel  unha actualización para %1$s.",
    "Update for %1$s to version %2$s is available." : "Está dispoñíbel unha actualización para %1$s á versión %2$s.",
    "Update for {app} to version %s is available." : "Está dispoñíbel unha actualización para {app} á versión %s.",
    "Update notification" : "Notificación de actualización",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Amosa as notificacións de actualizacións para o Nexcloud e fornece o SSO para o actualizador.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versión que ten en execución xa non dispón de mantemento. Asegúrese de actualizar a unha versión asistida tecnicamente tan cedo como lle sexa posíbel.",
    "Apps missing updates" : "Aplicativos con actualizacións non dispoñíbeis",
    "View in store" : "Ver na tenda",
    "Apps with available updates" : "Aplicativos con actualizacións dispoñíbeis",
    "Open updater" : "Abrir o actualizador",
    "Download now" : "Descargar agora",
    "What's new?" : "Que hai de novo?",
    "The update check is not yet finished. Please refresh the page." : "A comprobación de actualización aínda non rematou. Recargue a páxina.",
    "Your version is up to date." : "A súa versión está actualizada.",
    "A non-default update server is in use to be checked for updates:" : "Está en uso un servidor de actualizacións que non é o predeterminado para comprobar as actualizacións:",
    "Update channel:" : "Canle de actualización:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre poderá actualizar á versión más recente, mais nunca poderá volver a unha canle máis estábel.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Teña en conta que após a publicación dunha nova versión pode levar algún tempo antes de que se amose aiquí. Programamos novas versións ao longo do tempo para os nosos usuarios e por veces omitimos unha versión cando se atopan incidentes.",
    "Notify members of the following groups about available updates:" : "Notificar aos membros dos seguintes grupos sobre actualizacións dispoñíbeis:",
    "Only notification for app updates are available." : "Só están dispoñíbeis as notificacións para actualizacións de aplicativos.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A canle de actualización seleccionada fai obsoletas as notificacións dedicadas para o servidor.",
    "The selected update channel does not support updates of the server." : "A canle de actualización seleccionada non admite actualizacións do servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Hai dispoñíbel unha versión nova:<strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Comprobado o {lastCheckedDate}",
    "Checking apps for compatible updates" : "Comprobando as actualizacións compatíbeis cos aplicativos",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Asegúrese de que o seu config.php non ten configurado <samp>appstoreenabled</samp> como «false».",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Non foi posíbel conectar coa tenda de aplicativos ou esta non devolveu ningunha actualización. Busque as actualizacións  manualmente ou asegúrese de que o seu servidor ten acceso á Internet e pode conectarse coa tenda de aplicativos.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Todos</strong> os aplicativos teñen unha actualización dispoñíbel para esta versión",
    "View changelog" : "Ver o rexistro de cambios",
    "Enterprise" : "Empresarial",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Ofrece sempre o último nivel de parches, pero non se actualizará inmediatamente á seguinte versión principal. Esta actualización prodúcese unha vez que Nextcloud GmbH teña feitas as probas e reforzos para implementacións a gran escala e de obxectivos críticos. Esta canle só está dispoñíbel para os clientes e fornece o paquete Nextcloud empresarial.",
    "Stable" : "Estábel",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versión estábel máis recente. É axeitada para uso en produción e actualizarase sempre á última versión maior.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Unha versión preliminar só para probar funcionalidades novas, non para contornos de produción",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong>  aplicación non ten unha actualización dispoñíbel para esta versión","<strong>%n</strong> aplicativos non teñen unha actualización dispoñíbel para esta versión"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Sempre poderá actualizar á versión más recente ou á canle experimental, mais nunca poderá volver a unha canle máis estábel.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>production</strong> fornecerá sempre o último nivel de parches, mais non se actualizará á seguinte versión maior de inmediato. Esa actualización xeralmente acontece coa segunda publicación menor (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> é a versión estábel máis recente. É axeitada para uso en produción e actualizarase sempre á última versión maior.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> é unha versión preliminar só para probar funcionalidades novas, non para contornos de produción.",
    "Could not start updater, please try the manual update" : "Non foi posíbel iniciar o actualizador, tente a actualización manualmente",
    "Production" : "Produción",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Fornecerá sempre o último nivel de parches, mais non se actualizará á seguinte versión maior de inmediato. Esa actualización xeralmente acontece coa segunda publicación menor (x.0.2) e só se a instancia está xa na última versión menor."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/gl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está dispoñíbel. Obteña máis información sobre como actualizar.",
    "Channel updated" : "Canle actualizada",
    "Update notifications" : "Actualizar as notificacións",
    "The update server could not be reached since %d days to check for new updates." : "Non foi posíbel acadar o servidor de actualizacións dende hai %d días para comprobar se hai novas actualizacións.",
    "Please check the Nextcloud and server log files for errors." : "Revise os ficheiros de rexistro de Nextcloud e do servidor na busca de erros.",
    "Update to %1$s is available." : "Está dispoñíbel  unha actualización para %1$s.",
    "Update for %1$s to version %2$s is available." : "Está dispoñíbel unha actualización para %1$s á versión %2$s.",
    "Update for {app} to version %s is available." : "Está dispoñíbel unha actualización para {app} á versión %s.",
    "Update notification" : "Notificación de actualización",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Amosa as notificacións de actualizacións para o Nexcloud e fornece o SSO para o actualizador.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versión que ten en execución xa non dispón de mantemento. Asegúrese de actualizar a unha versión asistida tecnicamente tan cedo como lle sexa posíbel.",
    "Apps missing updates" : "Aplicacións con actualizacións non dispoñíbeis",
    "View in store" : "Ver na tenda",
    "Apps with available updates" : "Aplicacións con actualizacións dispoñíbeis",
    "Open updater" : "Abrir o actualizador",
    "Download now" : "Descargar agora",
    "What's new?" : "Que hai de novo?",
    "The update check is not yet finished. Please refresh the page." : "A comprobación de actualización aínda non rematou. Recargue a páxina.",
    "Your version is up to date." : "A súa versión está actualizada.",
    "A non-default update server is in use to be checked for updates:" : "Está en uso un servidor de actualizacións que non é o predeterminado para comprobar as actualizacións:",
    "Update channel:" : "Canle de actualización:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre poderá actualizar á versión más recente, mais nunca poderá volver a unha canle máis estábel.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Teña en conta que após a publicación dunha nova versión pode levar algún tempo antes de que se amose aiquí. Programamos novas versións ao longo do tempo para os nosos usuarios e por veces omitimos unha versión cando se atopan incidentes.",
    "Notify members of the following groups about available updates:" : "Notificar aos membros dos seguintes grupos sobre actualizacións dispoñíbeis:",
    "Only notification for app updates are available." : "Só están dispoñíbeis as notificacións para actualizacións de aplicacións.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A canle de actualización seleccionada fai obsoletas as notificacións dedicadas para o servidor.",
    "The selected update channel does not support updates of the server." : "A canle de actualización seleccionada non admite actualizacións do servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Hai dispoñíbel unha versión nova:<strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Comprobado o {lastCheckedDate}",
    "Checking apps for compatible updates" : "Comprobando as actualizacións compatíbeis coas aplicacións",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Asegúrese de que o seu config.php non ten configurado <samp>appstoreenabled</samp> como «false».",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Non foi posíbel conectar coa tenda de aplicacións ou esta non devolveu ningunha actualización. Busque as actualizacións  manualmente ou asegúrese de que o seu servidor ten acceso á Internet e pode conectarse coa tenda de aplicacións.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Todas</strong> as aplicacións teñen unha actualización dispoñíbel para esta versión",
    "View changelog" : "Ver o rexistro de cambios",
    "Enterprise" : "Empresarial",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Ofrece sempre o último nivel de parches, pero non se actualizará inmediatamente á seguinte versión principal. Esta actualización prodúcese unha vez que Nextcloud GmbH teña feitas as probas e reforzos para implementacións a gran escala e de obxectivos críticos. Esta canle só está dispoñíbel para os clientes e fornece o paquete Nextcloud empresarial.",
    "Stable" : "Estábel",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versión estábel máis recente. É axeitada para uso en produción e actualizarase sempre á última versión maior.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Unha versión preliminar só para probar funcionalidades novas, non para contornos de produción",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong>  aplicación non ten unha actualización dispoñíbel para esta versión","<strong>%n</strong> aplicacións non teñen unha actualización dispoñíbel para esta versión"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Sempre poderá actualizar á versión más recente ou á canle experimental, mais nunca poderá volver a unha canle máis estábel.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>production</strong> fornecerá sempre o último nivel de parches, mais non se actualizará á seguinte versión maior de inmediato. Esa actualización xeralmente acontece coa segunda publicación menor (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> é a versión estábel máis recente. É axeitada para uso en produción e actualizarase sempre á última versión maior.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> é unha versión preliminar só para probar funcionalidades novas, non para contornos de produción.",
    "Production" : "Produción",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Fornecerá sempre o último nivel de parches, mais non se actualizará á seguinte versión maior de inmediato. Esa actualización xeralmente acontece coa segunda publicación menor (x.0.2) e só se a instancia está xa na última versión menor."
},
"nplurals=2; plural=(n != 1);");
